@@ -1,5 +1,5 @@
 #import inspect
-import utils.utils as utils #import int2hex, convert_hex, encodeBech32AddressToHex
+import defichainUtils.utils.utils as utils #import int2hex, convert_hex, encodeBech32AddressToHex
 from dataclasses import dataclass, is_dataclass
 
 
